pub struct TokenTransferDbObj {Show 14 fields
pub id: i64,
pub payment_id: Option<String>,
pub from_addr: String,
pub receiver_addr: String,
pub chain_id: i64,
pub token_addr: Option<String>,
pub token_amount: String,
pub deposit_id: Option<String>,
pub deposit_finish: i64,
pub create_date: DateTime<Utc>,
pub tx_id: Option<i64>,
pub paid_date: Option<DateTime<Utc>>,
pub fee_paid: Option<String>,
pub error: Option<String>,
}Fields
id: i64payment_id: Option<String>from_addr: Stringreceiver_addr: Stringchain_id: i64token_addr: Option<String>token_amount: Stringdeposit_id: Option<String>If set payment done from internal deposit
deposit_finish: i64create_date: DateTime<Utc>The time when the record is inserted into the database It is override when inserting new entry to db
tx_id: Option<i64>paid_date: Option<DateTime<Utc>>fee_paid: Option<String>error: Option<String>Trait Implementations
Sourceimpl Clone for TokenTransferDbObj
impl Clone for TokenTransferDbObj
Sourcefn clone(&self) -> TokenTransferDbObj
fn clone(&self) -> TokenTransferDbObj
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TokenTransferDbObj
impl Debug for TokenTransferDbObj
Sourceimpl<'de> Deserialize<'de> for TokenTransferDbObj
impl<'de> Deserialize<'de> for TokenTransferDbObj
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TokenTransferDbObj, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TokenTransferDbObj, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a, R> FromRow<'a, R> for TokenTransferDbObjwhere
R: Row,
&'a str: ColumnIndex<R>,
i64: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
Option<String>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
String: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
DateTime<Utc>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
Option<i64>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
Option<DateTime<Utc>>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
impl<'a, R> FromRow<'a, R> for TokenTransferDbObjwhere
R: Row,
&'a str: ColumnIndex<R>,
i64: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
Option<String>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
String: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
DateTime<Utc>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
Option<i64>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
Option<DateTime<Utc>>: Decode<'a, <R as Row>::Database> + Type<<R as Row>::Database>,
Sourceimpl Serialize for TokenTransferDbObj
impl Serialize for TokenTransferDbObj
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more